import { isLinkHttp, removeEndingSlash, removeLeadingSlash, } from "@vuepress/shared";
import { deepAssign } from "vuepress-shared";
import { compareDate, resolveUrl } from "./utils.js";
export const ensureHostName = (options) => {
    // make sure hostname do not end with `/`
    if (options.hostname) {
        options.hostname = isLinkHttp(options.hostname)
            ? removeEndingSlash(options.hostname)
            : `https://${removeEndingSlash(options.hostname)}`;
        return true;
    }
    return false;
};
export const checkOutput = (options) => 
// some locales request output
(options.locales &&
    Object.entries(options.locales).some(([, { atom, json, rss }]) => atom || json || rss)) ||
    // root option requsts output
    Boolean(options.atom || options.json || options.rss);
export const getFeedOptions = ({ siteData }, options) => Object.fromEntries(Object.keys({
    // root locale must exists
    // eslint-disable-next-line @typescript-eslint/naming-convention
    "/": {},
    ...siteData.locales,
}).map((localePath) => [
    localePath,
    {
        // default values
        filter: ({ frontmatter, filePathRelative }) => !(frontmatter["home"] ||
            !filePathRelative ||
            frontmatter["article"] === false ||
            frontmatter["feed"] === false),
        sorter: (pageA, pageB) => compareDate(pageA.data.git?.createdTime
            ? new Date(pageA.data.git?.createdTime)
            : pageA.frontmatter.date, pageB.data.git?.createdTime
            ? new Date(pageB.data.git?.createdTime)
            : pageB.frontmatter.date),
        ...options,
        ...options.locales?.[localePath],
        // make sure hostname is not been overrided
        hostname: options.hostname,
    },
]));
export const getFeedChannelOption = (app, options, localePath = "") => {
    const { base } = app.options;
    const { title, description, lang, locales } = app.siteData;
    const { hostname, icon, image } = options;
    const author = options.channel?.author?.name;
    const defaultChannelOpion = {
        title: locales[localePath]?.title || title || locales["/"]?.title || "",
        link: resolveUrl(hostname, base, localePath),
        description: locales[localePath]?.description ||
            description ||
            locales["/"]?.description ||
            "",
        language: locales[localePath]?.lang || lang,
        copyright: author ? `Copyright by ${author}` : "",
        pubDate: new Date(),
        lastUpdated: new Date(),
        ...(icon ? { icon } : {}),
        ...(image ? { image } : {}),
        ...(author ? { author: { name: author } } : {}),
    };
    return deepAssign(defaultChannelOpion, options.channel || {});
};
export const getFilename = (options, prefix = "/") => ({
    atomOutputFilename: `${removeLeadingSlash(prefix)}${options.atomOutputFilename || "atom.xml"}`,
    jsonOutputFilename: `${removeLeadingSlash(prefix)}${options.jsonOutputFilename || "feed.json"}`,
    rssOutputFilename: `${removeLeadingSlash(prefix)}${options.rssOutputFilename || "rss.xml"}`,
});
export const getFeedLinks = ({ options: { base } }, options) => {
    const { hostname } = options;
    const { atomOutputFilename, jsonOutputFilename, rssOutputFilename } = getFilename(options);
    return {
        atom: resolveUrl(hostname, base, atomOutputFilename),
        json: resolveUrl(hostname, base, jsonOutputFilename),
        rss: resolveUrl(hostname, base, rssOutputFilename),
    };
};
//# sourceMappingURL=options.js.map